==> open-cluster-management-policy-model-6.4.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PolicySpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PolicySpecFluent<A extends PolicySpecFluent<A>> extends Fluent<A>{
  public Boolean getDisabled();
  public A withDisabled(Boolean disabled);
  public Boolean hasDisabled();
  public A addToPolicyTemplates(Integer index,PolicyTemplate item);
  public A setToPolicyTemplates(Integer index,PolicyTemplate item);
  public A addToPolicyTemplates(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyTemplate... items);
  public A addAllToPolicyTemplates(Collection<PolicyTemplate> items);
  public A removeFromPolicyTemplates(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyTemplate... items);
  public A removeAllFromPolicyTemplates(Collection<PolicyTemplate> items);
  public A removeMatchingFromPolicyTemplates(Predicate<PolicyTemplateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPolicyTemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PolicyTemplate> getPolicyTemplates();
  public List<PolicyTemplate> buildPolicyTemplates();
  public PolicyTemplate buildPolicyTemplate(Integer index);
  public PolicyTemplate buildFirstPolicyTemplate();
  public PolicyTemplate buildLastPolicyTemplate();
  public PolicyTemplate buildMatchingPolicyTemplate(Predicate<PolicyTemplateBuilder> predicate);
  public Boolean hasMatchingPolicyTemplate(Predicate<PolicyTemplateBuilder> predicate);
  public A withPolicyTemplates(List<PolicyTemplate> policyTemplates);
  public A withPolicyTemplates(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyTemplate... policyTemplates);
  public Boolean hasPolicyTemplates();
  public PolicySpecFluent.PolicyTemplatesNested<A> addNewPolicyTemplate();
  public PolicySpecFluent.PolicyTemplatesNested<A> addNewPolicyTemplateLike(PolicyTemplate item);
  public PolicySpecFluent.PolicyTemplatesNested<A> setNewPolicyTemplateLike(Integer index,PolicyTemplate item);
  public PolicySpecFluent.PolicyTemplatesNested<A> editPolicyTemplate(Integer index);
  public PolicySpecFluent.PolicyTemplatesNested<A> editFirstPolicyTemplate();
  public PolicySpecFluent.PolicyTemplatesNested<A> editLastPolicyTemplate();
  public PolicySpecFluent.PolicyTemplatesNested<A> editMatchingPolicyTemplate(Predicate<PolicyTemplateBuilder> predicate);
  public String getRemediationAction();
  public A withRemediationAction(String remediationAction);
  public Boolean hasRemediationAction();
  public A withDisabled();
  public interface PolicyTemplatesNested<N> extends Nested<N>,PolicyTemplateFluent<PolicySpecFluent.PolicyTemplatesNested<N>>{
    public N and();
    public N endPolicyTemplate();
    
  }
  
}

==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PolicySpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PolicySpecFluent<A extends PolicySpecFluent<A>> extends Fluent<A>{
  public Boolean getDisabled();
  public A withDisabled(Boolean disabled);
  public Boolean hasDisabled();
  public A addToPolicyTemplates(int index,PolicyTemplate item);
  public A setToPolicyTemplates(int index,PolicyTemplate item);
  public A addToPolicyTemplates(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyTemplate... items);
  public A addAllToPolicyTemplates(Collection<PolicyTemplate> items);
  public A removeFromPolicyTemplates(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyTemplate... items);
  public A removeAllFromPolicyTemplates(Collection<PolicyTemplate> items);
  public A removeMatchingFromPolicyTemplates(Predicate<PolicyTemplateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPolicyTemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PolicyTemplate> getPolicyTemplates();
  public List<PolicyTemplate> buildPolicyTemplates();
  public PolicyTemplate buildPolicyTemplate(int index);
  public PolicyTemplate buildFirstPolicyTemplate();
  public PolicyTemplate buildLastPolicyTemplate();
  public PolicyTemplate buildMatchingPolicyTemplate(Predicate<PolicyTemplateBuilder> predicate);
  public Boolean hasMatchingPolicyTemplate(Predicate<PolicyTemplateBuilder> predicate);
  public A withPolicyTemplates(List<PolicyTemplate> policyTemplates);
  public A withPolicyTemplates(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyTemplate... policyTemplates);
  public Boolean hasPolicyTemplates();
  public PolicySpecFluent.PolicyTemplatesNested<A> addNewPolicyTemplate();
  public PolicySpecFluent.PolicyTemplatesNested<A> addNewPolicyTemplateLike(PolicyTemplate item);
  public PolicySpecFluent.PolicyTemplatesNested<A> setNewPolicyTemplateLike(int index,PolicyTemplate item);
  public PolicySpecFluent.PolicyTemplatesNested<A> editPolicyTemplate(int index);
  public PolicySpecFluent.PolicyTemplatesNested<A> editFirstPolicyTemplate();
  public PolicySpecFluent.PolicyTemplatesNested<A> editLastPolicyTemplate();
  public PolicySpecFluent.PolicyTemplatesNested<A> editMatchingPolicyTemplate(Predicate<PolicyTemplateBuilder> predicate);
  public String getRemediationAction();
  public A withRemediationAction(String remediationAction);
  public Boolean hasRemediationAction();
  public A withDisabled();
  public interface PolicyTemplatesNested<N> extends Nested<N>,PolicyTemplateFluent<PolicySpecFluent.PolicyTemplatesNested<N>>{
    public N and();
    public N endPolicyTemplate();
    
  }
  
}
